% Constants
A_real = 54; % Actual surface area in m^2
V_pond = 781.250; % Volume of water in the pond in m^3

% Data: cumulative leaching amounts (ug/L) for various metals after 4 rainfall events
% M3
N8020_F1 = [0.91; 22; 1.4; 20; 0.77; 25.7];
PNEC_8020_F1 = [114.7; 2900; 6.3; 410; 34; 14.4];
metals_M3_f1 = {'Ba', 'B', 'Cu', 'Mg', 'Mn', 'Zn'};

% Rain intensity parameters (in m/h)
rain_min = 0.005;
rain_max = 0.015;

% Number of Monte Carlo samples
numSamples = 10000;

% Preallocate arrays for storing results
PEC_PNEC_combined = zeros(numSamples, length(N8020_F1));
deterministic_PEC_PNEC_combined = zeros(length(N8020_F1), 1);

% Monte Carlo simulation to generate PEC/PNEC ratios
for i = 1:length(N8020_F1)
    % Simulate leaching concentrations (C_L) using exponential distribution
    data = [0; N8020_F1(i)];
    expParams = mle(data, 'distribution', 'exponential');
    lambda = expParams;
    C_L = exprnd(lambda, numSamples, 1);
    
    % Simulate rain intensities (H_i) between 0.005 and 0.015
    H_i = rain_min + (rain_max - rain_min) * rand(numSamples, 1);
    
    % Calculate real leaching concentration (C_L_real) using the corrected formula
    C_L_real = (C_L .* H_i .* A_real) / V_pond;
    
    % Calculate PEC/PNEC ratio
    PEC_PNEC = C_L_real / PNEC_8020_F1(i);
    
    % Store PEC/PNEC ratios for this metal
    PEC_PNEC_combined(:, i) = PEC_PNEC;
    
    % Deterministic approach using mean leaching concentration and mid-point rain intensity
    deterministic_C_L = N8020_F1(i);
    deterministic_H_i = (rain_min + rain_max) / 2;
    deterministic_C_L_real = (deterministic_C_L * deterministic_H_i * A_real) / V_pond;
    deterministic_PEC_PNEC_combined(i) = deterministic_C_L_real / PNEC_8020_F1(i);
end

% Plot results: Histogram and deterministic comparison
figure;
for i = 1:length(N8020_F1)
    subplot(2, 3, i);
    histogram(PEC_PNEC_combined(:, i), 50, 'Normalization', 'pdf');
    hold on;
    xline(deterministic_PEC_PNEC_combined(i), 'r', 'LineWidth', 2, 'DisplayName', 'Deterministic');
    xline(mean(PEC_PNEC_combined(:, i)), 'b', 'LineWidth', 2, 'DisplayName', 'Monte Carlo Mean');
    hold off;
    title(['PEC/PNEC for ', metals_M3_f1{i}]);
    xlabel('PEC/PNEC');
    ylabel('PDF');
    legend('show', 'Location', 'best');
end

% Display summary statistics
disp('PEC/PNEC Ratio Summary for Combined Sensitivity Analysis:');
for i = 1:length(metals_M3_f1)
    disp(['Metal: ', metals_M3_f1{i}]);
    disp(['Mean (Monte Carlo): ', num2str(mean(PEC_PNEC_combined(:, i)))]);
    disp(['Median (Monte Carlo): ', num2str(median(PEC_PNEC_combined(:, i)))]);
    disp(['Standard Deviation (Monte Carlo): ', num2str(std(PEC_PNEC_combined(:, i)))]);
    disp(['95th Percentile (Monte Carlo): ', num2str(prctile(PEC_PNEC_combined(:, i), 95))]);
    disp(['Exceedance Probability (PEC/PNEC > 1) (Monte Carlo): ', num2str(mean(PEC_PNEC_combined(:, i) > 1))]);
    disp(['Deterministic PEC/PNEC Ratio: ', num2str(deterministic_PEC_PNEC_combined(i))]);
    disp(' ');
end

% Plot the boxplot of PEC/PNEC ratios for the combined sensitivity analysis
figure;
hold on;

% Create boxplot without colors
boxplot(PEC_PNEC_combined, 'Labels', metals_M3_f1);

% Plot deterministic results as points with colors
colors = lines(length(metals_M3_f1));
for i = 1:length(metals_M3_f1)
    scatter(i, deterministic_PEC_PNEC_combined(i), 100, 'filled', 'MarkerEdgeColor', 'k', 'MarkerFaceColor', colors(i, :));
end

% Customize plot labels and title
title('PEC/PNEC Ratio Variation for Combined Sensitivity Analysis');
xlabel('Metals');
ylabel('PEC/PNEC Ratio');
set(gca, 'YScale', 'log');
yline(1, '-', 'Threshold');
hold off;
