% Constants
intensity = 0.005; % Rain intensity in m/h
A_real = 54; % Actual surface area in m^2
V_pond = 781.250; % Volume of water in the pond in m^3

% Data: cumulative leaching amounts (ug/L) for various metals after 4 rainfall events
% M4
N8040_F1 = [1.69; 29; 6.7; 704; 8.96; 420.841; 85.8];
PNEC_8040_F1 = [114.7; 2900; 6.3; 410; 34; 10.5; 14.4];
metals_M4_f1 = {'Ba', 'B', 'Cu', 'Mg', 'Mn','P', 'Zn'};

% Number of Monte Carlo samples
numSamples = 10000;

% Preallocate arrays for storing results
PEC_PNEC_M4F1_case1 = zeros(numSamples, length(N8040_F1));
deterministic_PEC_PNEC = zeros(length(N8040_F1), 1);

    % Monte Carlo simulation to generate PEC/PNEC ratios
for i = 1:length(N8040_F1)
    % Fit an exponential distribution to the leaching data
    data = [0; N8040_F1(i)];
    expParams = mle(data, 'distribution', 'exponential');
    
    % Simulate leaching concentrations (C_L)
    C_L = exprnd(expParams, numSamples, 1);
    
    % Calculate real leaching concentration (C_L_real) using the corrected formula
    C_L_real = (C_L * intensity * A_real) / V_pond;
    
    % Calculate PEC/PNEC ratio
    PEC_PNEC = C_L_real / PNEC_8040_F1(i);
    
    % Store PEC/PNEC ratios for this metal
    PEC_PNEC_M4F1_case1(:, i) = PEC_PNEC;
    
    % Deterministic approach
    deterministic_C_L_real = (N8040_F1(i) * intensity * A_real) / V_pond;
    deterministic_PEC_PNEC(i) = deterministic_C_L_real / PNEC_8040_F1(i);
end 
    
    % Plot the PEC/PNEC ratio as histogram and deterministic comparison
    figure;
    for i = 1:length(N8040_F1)
    subplot(3, 3, i);
    histogram(PEC_PNEC_M4F1_case1(:, i), 50, 'Normalization', 'pdf');
    hold on;
    m1 = xline(deterministic_PEC_PNEC(i), 'r', 'LineWidth', 2, 'DisplayName', 'Deterministic');
    m2 = xline(mean(PEC_PNEC_M4F1_case1(:, i)), 'b', 'LineWidth', 2, 'DisplayName', 'Monte Carlo Mean');
    hold off;
    title(['PEC/PNEC for ', metals_M4_f1{i}]);
    xlabel('PEC/PNEC');
    ylabel('PDF');
    legend([m1,m2],{'Deterministic', 'Monte Carlo mean'});
    %legend([deterministic_line, monte_carlo_line], 'Location', 'best');
    end

% Plot the boxplot of PEC/PNEC ratios for Sensitivity Case 1
figure;
hold on;

% Create boxplot without colors
boxplot(PEC_PNEC_M4F1_case1, 'Labels', metals_M4_f1);

% Plot deterministic results as points with colors
colors = lines(length(metals_M4_f1));
for i = 1:length(metals_M4_f1)
    scatter(i, deterministic_PEC_PNEC(i), 100, 'filled', 'MarkerEdgeColor', 'k', 'MarkerFaceColor', colors(i, :));
end

% Customize plot labels and title
title('PEC/PNEC Ratio Variation for Simulated Leaching');
xlabel('Metals');
ylabel('PEC/PNEC Ratio');
set(gca, 'YScale', 'log');
yline(1, '-', 'Threshold');
hold off;

% Display numerical values for PEC/PNEC ratios
disp('PEC/PNEC Ratio Summary for Sensitivity Case 1:');
for i = 1:length(metals_M4_f1)
    disp(['Metal: ', metals_M4_f1{i}]);
    disp(['Mean (Monte Carlo): ', num2str(mean(PEC_PNEC_M4F1_case1(:, i)))]);
    disp(['Median (Monte Carlo): ', num2str(median(PEC_PNEC_M4F1_case1(:, i)))]);
    disp(['Standard Deviation (Monte Carlo): ', num2str(std(PEC_PNEC_M4F1_case1(:, i)))]);
    disp(['95th Percentile (Monte Carlo): ', num2str(prctile(PEC_PNEC_M4F1_case1(:, i), 95))]);
    disp(['Exceedance Probability (PEC/PNEC > 1) (Monte Carlo): ', num2str(mean(PEC_PNEC_M4F1_case1(:, i) > 1))]);
    disp(['Deterministic PEC/PNEC Ratio: ', num2str(deterministic_PEC_PNEC(i))]);
    disp(' ');
end
