% Constants
A_real = 54; % Actual surface area in m^2
V_pond = 781.250; % Volume of water in the pond in m^3

% Data: cumulative leaching amounts (ug/L) for various metals after 4 rainfall events
% M4
N8040_F1 = [1.69; 29; 6.7; 704; 8.96; 420.841; 85.8];
PNEC_8040_F1 = [114.7; 2900; 6.3; 410; 34; 10.5; 14.4];
metals_M4_f1 = {'Ba', 'B', 'Cu', 'Mg', 'Mn','P', 'Zn'};

% Rain intensity parameters (in m/h)
rain_min = 0.005;
rain_max = 0.015;

% Number of Monte Carlo samples
numSamples = 10000;

% Sensitivity Case 1: Simulating leaching concentration with fixed rain intensity
PEC_PNEC_case1 = zeros(numSamples, length(N8040_F1));
for i = 1:length(N8040_F1)
    % Simulate leaching concentrations (C_L) using exponential distribution
    data = [0; N8040_F1(i)];
    expParams = mle(data, 'distribution', 'exponential');
    lambda = expParams;
    C_L = exprnd(lambda, numSamples, 1);
    
    % Fixed rain intensity
    intensity = (rain_min + rain_max) / 2;
    
    % Calculate real leaching concentration (C_L_real) using the corrected formula
    C_L_real = (C_L * intensity * A_real) / V_pond;
    
    % Calculate PEC/PNEC ratio
    PEC_PNEC = C_L_real / PNEC_8040_F1(i);
    
    % Store PEC/PNEC ratios for this metal
    PEC_PNEC_case1(:, i) = PEC_PNEC;
end

% Sensitivity Case 2: Fixed leaching concentration with simulated rain intensity
PEC_PNEC_case2 = zeros(numSamples, length(N8040_F1));
for i = 1:length(N8040_F1)
    % Fixed leaching concentration (C_L)
    C_L = N8040_F1(i);
    
    % Simulate rain intensities (H_i) between 0.005 and 0.015
    H_i = rain_min + (rain_max - rain_min) * rand(numSamples, 1);
    
    % Calculate real leaching concentration (C_L_real) using the corrected formula
    C_L_real = (C_L * H_i * A_real) / V_pond;
    
    % Calculate PEC/PNEC ratio
    PEC_PNEC = C_L_real / PNEC_8040_F1(i);
    
    % Store PEC/PNEC ratios for this metal
    PEC_PNEC_case2(:, i) = PEC_PNEC;
end

% Sensitivity Case 3: Both leaching concentration and rain intensity simulated
PEC_PNEC_case3 = zeros(numSamples, length(N8040_F1));
for i = 1:length(N8040_F1)
    % Simulate leaching concentrations (C_L) using exponential distribution
    data = [0; N8040_F1(i)];
    expParams = mle(data, 'distribution', 'exponential');
    lambda = expParams;
    C_L = exprnd(lambda, numSamples, 1);
    
    % Simulate rain intensities (H_i) between 0.005 and 0.015
    H_i = rain_min + (rain_max - rain_min) * rand(numSamples, 1);
    
    % Calculate real leaching concentration (C_L_real) using the corrected formula
    C_L_real = (C_L.*H_i.*A_real)./ V_pond;
    
    % Calculate PEC/PNEC ratio
    PEC_PNEC = C_L_real / PNEC_8040_F1(i);
    
    % Store PEC/PNEC ratios for this metal
    PEC_PNEC_case3(:, i) = PEC_PNEC;
end

% Create subplots to compare the three sensitivity cases
figure;

% Sensitivity Case 1
subplot(1, 3, 1);
boxplot(PEC_PNEC_case1, 'Labels', metals_M4_f1);
title('M4 N-1 s1');
xlabel('Metals');
ylabel('PEC/PNEC');
set(gca, 'YScale', 'log');
yline(1, '-', 'Threshold');

% Sensitivity Case 2
subplot(1, 3, 2);
boxplot(PEC_PNEC_case2, 'Labels', metals_M4_f1);
title('M4 N-1 s2');
xlabel('Metals');
ylabel('PEC/PNEC');
set(gca, 'YScale', 'log');
yline(1, '-', 'Threshold');
 ylim([1e-10 1e0]);

% Sensitivity Case 3
subplot(1, 3, 3);
boxplot(PEC_PNEC_case3, 'Labels', metals_M4_f1);
title('M4 N-1 s3');
xlabel('Metals');
ylabel('PEC/PNEC');
set(gca, 'YScale', 'log');
yline(1, '-', 'Threshold');
 ylim([1e-10 1e0]);

% Adjust layout and display the figure
%sgtitle('Comparison of PEC/PNEC Ratios for Different Sensitivity Cases');
